%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                       %
%    THE ENVIRONMENTAL MULTI-SECTOR DSGE MODEL EMuSe                    %
%                                                                       %
%    EMuSe has been developed by the                                    %
%    Directorate General Economics of the Deutsche Bundesbank.          %
%                                                                       %
%    Authors:                                                           %
%    Natascha Hinterlang                                                %
%    Anika Martin                                                       %
%    Oke Röhe                                                           %
%    Nikolai Stähler                                                    %
%    Johannes Strobel                                                   %
%                                                                       %
%    Contact: emuse@bundesbank.de                                       %
%                                                                       %
%    The authors are grateful to their colleagues in DG Economics,      %
%    DG Financial Stability and the Research Centre of Deutsche         %
%    Bundesbank, the Working Group on Econometric Modelling (WGEM) and  %
%    the Working Group on Forecasting (WGF) of the European System of   %
%    Central Banks (ESCB) as well as the members of the informal        %
%    network of modelling experts of the G7 Climate Change Mitigation   %
%    Working Group for their helpful discussions and valuable input     %
%    during the development of EMuSe.                                   %
%                                                                       %
%    If you use the EMuSe model, please cite                            %
%    Natascha Hinterlang, Anika Martin, Oke Röhe,                       %
%    Nikolai Stähler and Johannes Strobel (2023),                       %
%    The Environmental Multi-Sector DSGE model EMuSe:                   %
%    A technical documentation,                                         %
%    Deutsche Bundesbank Technical Paper, No. 03/2023.                  %                                                
%                                                                       %
%                                                                       %
% Access to EMuSe is only granted on the basis set out in the           %    
% accompanying End User License Agreement (EULA).                       %
% Downloading, installing or using the EMuSe model implies acceptance   % 
% of the EULA. If you do not agree to be bound by these terms,          %
% do not download, install or use the related Software and              %
% documentation. As further outlined in the EULA the Software           %
% is provided "as is", without any representation or warranty of any    %
% kind either express or implied.                                       %
%                                                                       %
% The Software and Derived Work from the Software may only be           %
% distributed and communicated together with a copy of the EULA and the %
% aforementioned notice.                                                %
%                                                                       %
%                                                                       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Housekeeping
clear;
close all;
clc;


%% Multi-sector model with flexible prices and climate module

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Pass objects to MATLAB that DYNARE will access later on. 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% When solving the model, we take the calibration file as given. This file contains the sectoral parameter values. 
load Calibration_EU28_10S.mat

% In order to match DSGE sector numbers with calibration sector codes (NACE):
NACE = string({'A','B','C','D','E','F','G_H_I','J','M_N', 'R_S'});
DSGE_sector = [1:size(NACE,2)];

% Match DSGE region names with the ones specified in calibration tool (ISO):
ISO = {'Reg_a'};
DSGE_country = {'a'};

%Write and adjust auxiliary files in order to execute the optimization of
%intermediate inputs and capital:
SS_file = 'SS_MSMod_10S_1C.mod';   % Write name of SS file here
make_getk_text(DSGE_sector,DSGE_country);
make_getk_SS_text(SS_file, DSGE_sector,DSGE_country);


%% Execute perfect foresight exercise: Simulate years 2005-2030
% Note: The following simulation is based on NGFS data. The model is
% parameterized to reflect 2005. Note, however, that the first simulated
% period is 2005 BEFORE the announcement of the changes in the carbon price
% and the carbon intensity, the second period is the 2005 AFTER that
% announcement. When plotting the results, 2005 after the announcement is
% the starting point. 

dynare MS_1C_Mod_simul_2005_2030.mod;
Save_Results_05to30;
    
    
%% Execute perfect foresight exercise: Simulate years 2031-2100

dynare MS_1C_Mod_simul_2031_2100.mod;
Save_Results_31to00;    



%% Process results: Start by loading...
clear;
clc;

cd Results

load TenS_SimulResults_TenS_FlexPrice_Disorderly_05to30
load TenS_SimulResults_TenS_FlexPrice_Disorderly_31to00
cd ..

%%
% Generate vectors of results such that households are surprised by carbon
% price increase starting in 2031. To this end, concatenate two simulations
% i) S1: First, generate simulation results from 2005-2030. In this 
% scenario, the carbon price increases from 2005-2030 and remains fixed at 
% the 2030 level thereafter. ii) S2: Second, generate simulation that runs 
% from 2030-2100. The model is initialed to the period 27 value (year 2030)
% of S1. iii) Finally, S1 and S2 are combined: 2005-2030 from S1, 
% 2031-2100 from S2.

index_sim_end_3100 = 71; % Index 71 is year 2100 in the simulation
index_ss_size = 100-index_sim_end_3100-1-3; % Periods in ss second 'Regime'; 

Y_a_t_3100_sim =  TenS_3100_Sim_results(strmatch('Y_a_t',TenS_3100_var_names,'exact'), 1:index_sim_end_3100) ;
Y_a_t_3100_ss_sim = [TenS_3100_Sim_ss(strmatch('Y_a_t',TenS_3100_var_names,'exact'))*ones(index_ss_size,1)' Y_a_t_3100_sim] ;

Y_VA_a_t_3100_sim =  TenS_3100_Sim_results(strmatch('Y_VA_a_t',TenS_3100_var_names,'exact'), 1:index_sim_end_3100) ;
Y_VA_a_t_3100_ss_sim = [TenS_3100_Sim_ss(strmatch('Y_VA_a_t',TenS_3100_var_names,'exact'))*ones(index_ss_size,1)' Y_VA_a_t_3100_sim] ;

P_EM_a_t_3100_sim =  TenS_3100_Sim_results(strmatch('P_EM_a_t',TenS_3100_var_names,'exact'), 1:index_sim_end_3100) ;
P_EM_a_t_3100_ss_sim = [TenS_3100_Sim_ss(strmatch('P_EM_a_t',TenS_3100_var_names,'exact'))*ones(index_ss_size,1)' P_EM_a_t_3100_sim] ;

ZZ_a_t_3100_sim =  TenS_3100_Sim_results(strmatch('ZZ_a_t',TenS_3100_var_names,'exact'), 1:index_sim_end_3100) ;
ZZ_a_t_3100_ss_sim = [TenS_3100_Sim_ss(strmatch('ZZ_a_t',TenS_3100_var_names,'exact'))*ones(index_ss_size,1)' ZZ_a_t_3100_sim] ;

% Concatenate the two simulations: First array: S1, Years 2005 (before
% announcement of carbon policies) until 2030; Second array: S2, Years 2031 until 2100.
Y_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('Y_a_t',TenS_0530_var_names,'exact'), 1:27) Y_a_t_3100_sim(2:index_sim_end_3100)];
Y_VA_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('Y_VA_a_t',TenS_0530_var_names,'exact'), 1:27) Y_VA_a_t_3100_sim(2:index_sim_end_3100)];

P_EM_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('P_EM_a_t',TenS_0530_var_names,'exact'), 1:27) P_EM_a_t_3100_sim(2:index_sim_end_3100)];
ZZ_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('ZZ_a_t',TenS_0530_var_names,'exact'), 1:27) ZZ_a_t_3100_sim(2:index_sim_end_3100)];


Y_1_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('Y_1_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('Y_1_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];
Y_2_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('Y_2_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('Y_2_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];
Y_3_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('Y_3_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('Y_3_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];
Y_4_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('Y_4_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('Y_4_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];
Y_5_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('Y_5_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('Y_5_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];
Y_6_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('Y_6_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('Y_6_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];
Y_7_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('Y_7_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('Y_7_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];
Y_8_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('Y_8_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('Y_8_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];
Y_9_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('Y_9_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('Y_9_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];
Y_10_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('Y_10_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('Y_10_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];

EM_1_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('EM_cost_1_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('EM_cost_1_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];
EM_2_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('EM_cost_2_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('EM_cost_2_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];
EM_3_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('EM_cost_3_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('EM_cost_3_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];
EM_4_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('EM_cost_4_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('EM_cost_4_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];
EM_5_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('EM_cost_5_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('EM_cost_5_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];
EM_6_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('EM_cost_6_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('EM_cost_6_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];
EM_7_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('EM_cost_7_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('EM_cost_7_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];
EM_8_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('EM_cost_8_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('EM_cost_8_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];
EM_9_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('EM_cost_9_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('EM_cost_9_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];
EM_10_a_t_0500_sim = [TenS_0530_Sim_results(strmatch('EM_cost_10_a_t',TenS_0530_var_names,'exact'), 1:27) TenS_3100_Sim_results(strmatch('EM_cost_10_a_t',TenS_3100_var_names,'exact'), 2:index_sim_end_3100)];



% Note: When concatening the vectors of the emissions intensity and
% computing the index for comparison purposes to the original NGFS series,
% We divide by the initial 2005 value both in simulation scenario 1 and 2 
% in order to generate an index that is unity in 2005. 

kappa_a_t_0500_sim_part1 = TenS_0530_Sim_results(strmatch('ZZ_a_t',TenS_0530_var_names,'exact'), 1:27)./TenS_0530_Sim_results(strmatch('Y_a_t',TenS_0530_var_names,'exact'), 1:27) ./ (TenS_0530_Sim_results(strmatch('ZZ_a_t',TenS_0530_var_names,'exact'), 1)./TenS_0530_Sim_results(strmatch('Y_a_t',TenS_0530_var_names,'exact'), 1));
kappa_a_t_0500_sim_part2=(ZZ_a_t_3100_sim(2:index_sim_end_3100)./Y_a_t_3100_sim(2:index_sim_end_3100)) ./ (TenS_0530_Sim_results(strmatch('ZZ_a_t',TenS_0530_var_names,'exact'), 1)./TenS_0530_Sim_results(strmatch('Y_a_t',TenS_0530_var_names,'exact'), 1)) ;
kappa_a_t_0500_sim = [kappa_a_t_0500_sim_part1 kappa_a_t_0500_sim_part2 ];

cd Results
save TenS_Simul_Results_Disorderly_Concatenate kappa_a_t_0500_sim ZZ_a_t_0500_sim P_EM_a_t_0500_sim Y_a_t_0500_sim Y_VA_a_t_0500_sim Y_1_a_t_0500_sim Y_2_a_t_0500_sim Y_3_a_t_0500_sim ...
     Y_4_a_t_0500_sim Y_5_a_t_0500_sim Y_6_a_t_0500_sim Y_7_a_t_0500_sim Y_8_a_t_0500_sim Y_9_a_t_0500_sim Y_10_a_t_0500_sim ... 
     EM_1_a_t_0500_sim EM_2_a_t_0500_sim EM_3_a_t_0500_sim EM_4_a_t_0500_sim EM_5_a_t_0500_sim EM_6_a_t_0500_sim EM_7_a_t_0500_sim EM_8_a_t_0500_sim EM_9_a_t_0500_sim EM_10_a_t_0500_sim
cd ..
 
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generate plots
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Figure_Simul_MS_PerfForesight;