%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                       %
%    THE ENVIRONMENTAL MULTI-SECTOR DSGE MODEL EMuSe                    %
%                                                                       %
%    EMuSe has been developed by the                                    %
%    Directorate General Economics of the Deutsche Bundesbank.          %
%                                                                       %
%    Authors:                                                           %
%    Natascha Hinterlang                                                %
%    Anika Martin                                                       %
%    Oke Rhe                                                           %
%    Nikolai Sthler                                                    %
%    Johannes Strobel                                                   %
%                                                                       %
%    Contact: emuse@bundesbank.de                                       %
%                                                                       %
%    The authors are grateful to their colleagues in DG Economics,      %
%    DG Financial Stability and the Research Centre of Deutsche         %
%    Bundesbank, the Working Group on Econometric Modelling (WGEM) and  %
%    the Working Group on Forecasting (WGF) of the European System of   %
%    Central Banks (ESCB) as well as the members of the informal        %
%    network of modelling experts of the G7 Climate Change Mitigation   %
%    Working Group for their helpful discussions and valuable input     %
%    during the development of EMuSe.                                   %
%                                                                       %
%    If you use the EMuSe model, please cite                            %
%    Natascha Hinterlang, Anika Martin, Oke Rhe,                       %
%    Nikolai Sthler and Johannes Strobel (2023),                       %
%    The Environmental Multi-Sector DSGE model EMuSe:                   %
%    A technical documentation,                                         %
%    Deutsche Bundesbank Technical Paper, No. 03/2023.                  %                                                
%                                                                       %
%                                                                       %
% Access to EMuSe is only granted on the basis set out in the           %    
% accompanying End User License Agreement (EULA).                       %
% Downloading, installing or using the EMuSe model implies acceptance   % 
% of the EULA. If you do not agree to be bound by these terms,          %
% do not download, install or use the related Software and              %
% documentation. As further outlined in the EULA the Software           %
% is provided "as is", without any representation or warranty of any    %
% kind either express or implied.                                       %
%                                                                       %
% The Software and Derived Work from the Software may only be           %
% distributed and communicated together with a copy of the EULA and the %
% aforementioned notice.                                                %
%                                                                       %
%                                                                       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Housekeeping

clear all;
close all;
clc;
store_cd = cd;

%% Preparing plots

% Initial year of simulation
startyear = 2005;

% Final year of simulation 
endyear = 2050;

% Needed for plots
comp_period = endyear - 2005 + 2; % Find index corresponding to endyear: Add "2", because the first period of simulation is 2005 BEFORE announcement of price path, second period is 2005 after announcement, third period is 2006 and so on ...

%% Load simulation results from MS model

cd Orderly\EMuSe\Results
load MS_SimulResults_MS_FlexPrice
cd(store_cd)

Orderly_TenS_param_names = MS_param_names;
Orderly_TenS_param_values = MS_param_values;
Orderly_TenS_Sim_results = MS_Sim_results;
Orderly_TenS_Sim_ss = MS_Sim_ss;
Orderly_TenS_var_names = MS_var_names;
clear('MS_param_names', 'MS_param_values','MS_Sim_results','MS_Sim_ss','MS_var_names');

% Get a vector with variable names:
% Note that first, the results for sectoral production are loaded.
% Below, the results for value added will replace the produced quantities,
% i.e. Y_1_a_t,...,Y_10_a_t will be replaced with
% real_value_added_1_a_t,...,real_value_added_10_a_t. Only aggregate value
% added is retained.

for i = 1:size(Orderly_TenS_Sim_results, 1) 
    Endo_names(i,1) = convertCharsToStrings(Orderly_TenS_var_names(i, 1:1)); 
end

%% Extract and process gross value added

findY = strcmp(Endo_names, 'Y');
Y_names_Orderly = Orderly_TenS_var_names(findY, :); % Open to see the Y's are in the "right" order: Aggregate GO, VA, 1,...,10 
Y_results_Orderly = Orderly_TenS_Sim_results(findY, :); 

nvar = size(Y_results_Orderly,1);
Y_results_Orderly_init_ss = Y_results_Orderly(1:nvar,1);  % Use 2005 as reference period
Y_results_Orderly_percdev = (Y_results_Orderly(1:nvar, 1:comp_period)./Y_results_Orderly_init_ss-1)*100;

%% Disorderly scenario 
% Note that the data are prepared already
cd Disorderly\EMuSe\Results
load TenS_Simul_Results_Disorderly_Concatenate
cd(store_cd)


%% Process

Y_results_Disorderly = [Y_a_t_0500_sim', Y_VA_a_t_0500_sim', Y_1_a_t_0500_sim', ...
Y_2_a_t_0500_sim', Y_3_a_t_0500_sim', Y_4_a_t_0500_sim', ...
Y_5_a_t_0500_sim', Y_6_a_t_0500_sim', Y_7_a_t_0500_sim', ...
Y_8_a_t_0500_sim', Y_9_a_t_0500_sim', Y_10_a_t_0500_sim'];

Y_results_Disorderly = Y_results_Disorderly';
Y_results_Disorderly_init_ss= Y_results_Disorderly(1:nvar,1);
Y_results_Disorderly_percdev = (Y_results_Disorderly(1:nvar, 1:comp_period)./Y_results_Disorderly_init_ss-1)*100; % Note: Initial steady states are identical, can divide using the one from the orderly scenario


%% Build stacked bar plots

Y_results_stackbar_percdev(:,1) = Y_results_Orderly_percdev(:,comp_period);
Y_results_stackbar_percdev(:,2) = Y_results_Disorderly_percdev(:,comp_period);
Y_results_stackbar_percdev(:,3) = Y_results_stackbar_percdev(:,2) - Y_results_stackbar_percdev(:,1);
Diff_GVA_agg_1  = (Y_results_Orderly_percdev(2,:)-Y_results_Disorderly_percdev(2,:)); 
Diff_GVA_agg_1  = Diff_GVA_agg_1(1, 19:comp_period);  % Start in 2022

%% Impact of climate policies on aggregate output

timeline = 2022:1:2050;
figure;

bar(timeline,(-1)*Diff_GVA_agg_1);
title(['Difference in real gross value added between a disorderly and an orderly transition in the EU'],'FontSize',18,'FontWeight','Bold');
 xlabel('Year')
ylabel('Percentage points')
 
 dim = [16,9];
 set(gcf,'paperpositionmode','manual','paperunits','inches');
 set(gcf,'papersize',dim,'paperposition',[0,0,dim]);
 print(gcf,'-dpdf','Figure_3_aggregate');

%% Plot impact of climate policies on sectoral output

figure;
bar(Y_results_stackbar_percdev([5 6 8 9 11],3)) 
set(gca, 'FontSize',12,'XTick',[1 2 3 4 5],'XTickLabel',{'NACE C','NACE D','NACE F','NACE G-I','NACE M-N'});
xtickangle(45);
title(['Difference in real gross output between a disorderly and an orderly transition in ',num2str(endyear)],'FontSize',15,'FontWeight','Bold');
xlabel('Sectors')
ylabel('Percentage Points')

dim = [16,9];
set(gcf,'paperpositionmode','manual','paperunits','inches');
set(gcf,'papersize',dim,'paperposition',[0,0,dim]);
print(gcf,'-dpdf','Figure_4_sectors');