%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                       %
%    THE ENVIRONMENTAL MULTI-SECTOR DSGE MODEL EMuSe                    %
%                                                                       %
%    EMuSe has been developed by the                                    %
%    Directorate General Economics of the Deutsche Bundesbank.          %
%                                                                       %
%    Authors:                                                           %
%    Natascha Hinterlang                                                %
%    Anika Martin                                                       %
%    Oke Röhe                                                           %
%    Nikolai Stähler                                                    %
%    Johannes Strobel                                                   %
%                                                                       %
%    Contact: emuse@bundesbank.de                                       %
%                                                                       %
%    The authors are grateful to their colleagues in DG Economics,      %
%    DG Financial Stability and the Research Centre of Deutsche         %
%    Bundesbank, the Working Group on Econometric Modelling (WGEM) and  %
%    the Working Group on Forecasting (WGF) of the European System of   %
%    Central Banks (ESCB) as well as the members of the informal        %
%    network of modelling experts of the G7 Climate Change Mitigation   %
%    Working Group for their helpful discussions and valuable input     %
%    during the development of EMuSe.                                   %
%                                                                       %
%    If you use the EMuSe model, please cite                            %
%    Natascha Hinterlang, Anika Martin, Oke Röhe,                       %
%    Nikolai Stähler and Johannes Strobel (2023),                       %
%    The Environmental Multi-Sector DSGE model EMuSe:                   %
%    A technical documentation,                                         %
%    Deutsche Bundesbank Technical Paper, No. 03/2023.                   %                                                
%                                                                       %
%                                                                       %
% Access to EMuSe is only granted on the basis set out in the           %    
% accompanying End User License Agreement (EULA).                       %
% Downloading, installing or using the EMuSe model implies acceptance   % 
% of the EULA. If you do not agree to be bound by these terms,          %
% do not download, install or use the related Software and              %
% documentation. As further outlined in the EULA the Software           %
% is provided "as is", without any representation or warranty of any    %
% kind either express or implied.                                       %
%                                                                       %
% The Software and Derived Work from the Software may only be           %
% distributed and communicated together with a copy of the EULA and the %
% aforementioned notice.                                                %
%                                                                       %
%                                                                       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Housekeeping
clear;
close all;
clc;
store_cd = cd;

%% Preparing plots

% Initial year of simulation
init_period = 2005;

% Find index of start year for plots
startyear = 2019 - init_period + 2; % Add 2 because the first period of simulation is 2005 BEFORE announcement of price path, second period is 2005 after announcement, third period is 2006 and so on...

% Final year of Simulation 
endyear = 2050;

% Find index of end year for plots
comp_period = endyear - init_period + 2; % Add 2 because the first period of simulation is 2005 BEFORE announcement of price path, second period is 2005 after announcement, third period is 2006 and so on...

%% Load simulation results from MS model

cd Orderly\TenS_Model\Results
load TenS_Aonly_Open_SimulResults_FlexPrice_Orderly_PEM
cd(store_cd)

Orderly_PEM_TenS_param_names = TenS_param_names;
Orderly_PEM_TenS_param_values = TenS_param_values;
Orderly_PEM_TenS_Sim_results = TenS_Sim_results;
Orderly_PEM_TenS_Sim_ss = TenS_Sim_ss;
Orderly_PEM_TenS_var_names = TenS_var_names;
clear('TenS_param_names', 'TenS_param_values','TenS_Sim_results','TenS_Sim_ss','TenS_var_names');

% Get a vector with variable names:
% Note that first, the results for sectoral production are loaded.
% Below, the results for value added will replace the produced quantities,
% i.e. Y_1_a_t,...,Y_10_a_t will be replaced with
% real_value_added_1_a_t,...,real_value_added_10_a_t. Only aggregate value
% added is retained.

for i = 1:size(Orderly_PEM_TenS_Sim_results, 1) 
    Endo_names(i,1) = convertCharsToStrings(Orderly_PEM_TenS_var_names(i, 1:1)); 
end

findY = strcmp(Endo_names, 'Y');
Y_names_PEM_Orderly = Orderly_PEM_TenS_var_names(findY, :); % Open to see the variables are in the "right" order
Y_results_PEM_Orderly = Orderly_PEM_TenS_Sim_results(findY, :);

Y_results_PEM_Orderly = Y_results_PEM_Orderly([3:12 15:end],:); % Select only sector-level variables
nvar = 10; % Number of sectors

%% Compute variables for figure

% Compute the change in output in region A from startyear to end year
Y_results_PEM_Orderly_init_ss_A = Y_results_PEM_Orderly(1:nvar, startyear);
Y_results_PEM_Orderly_init_ss_B = Y_results_PEM_Orderly(nvar+1:end, startyear);
Y_results_PEM_Orderly_percdev_A = (Y_results_PEM_Orderly(1:nvar, 1:comp_period)./Y_results_PEM_Orderly_init_ss_A-1)*100;

Y_results_PEM_Orderly_percdev_agg_A = ((sum(Y_results_PEM_Orderly(1:nvar, 1:comp_period),1))./(sum(Y_results_PEM_Orderly_init_ss_A,1))-1);
Y_results_PEM_Orderly_percdev_agg_B = ((sum(Y_results_PEM_Orderly(nvar+1:end, 1:comp_period),1))./(sum(Y_results_PEM_Orderly_init_ss_B,1))-1);

% Compute the change in share of sectoral value added from startyear to 
% end year
Y_results_PEM_Orderly_SecShare_2019_A = Y_results_PEM_Orderly(1:nvar,startyear) ./sum(Y_results_PEM_Orderly(1:nvar,startyear),1);
Y_results_PEM_Orderly_SecShare_2050_A = Y_results_PEM_Orderly(1:nvar,comp_period) ./sum(Y_results_PEM_Orderly(1:nvar,comp_period),1);


% Compute the change in the carbon content of trade flows start year to 
% end year
findMM = strcmp(Endo_names, 'M');
MM_names_PEM_Orderly = Orderly_PEM_TenS_var_names(findMM, :); %Open to see the variables are in the "right" order
MM_results_PEM_Orderly = Orderly_PEM_TenS_Sim_results(findMM, :);

findXX = strcmp(Endo_names, 'X');
XX_names_PEM_Orderly = Orderly_PEM_TenS_var_names(findXX, :); %Open to see the variables are in the "right" order
XX_results_PEM_Orderly = Orderly_PEM_TenS_Sim_results(findXX, :);

CC_results_PEM_Orderly = MM_results_PEM_Orderly - XX_results_PEM_Orderly;
CC_results_PEM_Orderly_init_ss_A = CC_results_PEM_Orderly(1:nvar, startyear);

CC_results_PEM_Orderly_percdev_A = (CC_results_PEM_Orderly(1:nvar, 1:comp_period)./CC_results_PEM_Orderly_init_ss_A-1)*100;

% Sectoral data

Y_results_stackbar_percdev(:,1) = Y_results_PEM_Orderly_percdev_A(:,comp_period); % PEM in A only
Y_results_stackbar_percdev(:,2) = Y_results_PEM_Orderly_SecShare_2019_A; % Carbon Policy (PEM) in A only
Y_results_stackbar_percdev(:,3) = Y_results_PEM_Orderly_SecShare_2050_A; % Carbon Policy (PEM) in A only
Y_results_stackbar_percdev(:,4) = Y_results_PEM_Orderly_SecShare_2050_A-Y_results_PEM_Orderly_SecShare_2019_A; % Carbon Policy (PEM) in A only
Y_results_stackbar_percdev(:,5) = CC_results_PEM_Orderly_percdev_A(:,comp_period); % PEM in A only

% Aggragate data

Y_results_stackbar_percdev_agg(1,:) = Y_results_PEM_Orderly_percdev_agg_A-Y_results_PEM_Orderly_percdev_agg_B;

Y_results_avg_aux_1 = (((1+Y_results_PEM_Orderly_percdev_agg_A(:,47))^(1/31))-1)*100;
Y_results_avg_aux_2 = (((1+Y_results_PEM_Orderly_percdev_agg_B(:,47))^(1/31))-1)*100;
Y_results_avg_agg(1,:) = Y_results_avg_aux_1-Y_results_avg_aux_2;



%% Plot figure

Sect_C_Results = Y_results_stackbar_percdev(3,[1 4 5])';

figure;

subplot(1,2,1)
bar(100*Sect_C_Results([2]))
set(gca, 'FontSize',10,'XTick',[1],'XTickLabel',{});
xtickangle(45);
title(["Share in gross output in region A"],'FontSize',18,'FontWeight','normal');
xlabel('')
ylabel('PP Change compared to 2019')


subplot(1,2,2)
bar(Sect_C_Results([3]))
set(gca, 'FontSize',10,'XTick',[1],'XTickLabel',{});
xtickangle(45);
title(["Carbon content of net imports"],'FontSize',18,'FontWeight','normal');
xlabel('')
ylabel('% Change compared to 2019')

sgtitle(['Manufacturing (NACE C) - ',num2str(endyear) ' relative to 2019'], 'FontSize', 28,'FontWeight','bold')

dim = [16,9];
set(gcf,'paperpositionmode','manual','paperunits','inches');
set(gcf,'papersize',dim,'paperposition',[0,0,dim]);
print(gcf,'-dpdf','Figure_6_two_region');
